==> range-8.x-1.1-rc1.tar.gz: range/src/Plugin/views/filter/Range.php <==
<?php

namespace Drupal\range\Plugin\views\filter;

use Drupal\Core\Form\FormStateInterface;
use Drupal\views\Plugin\views\filter\FilterPluginBase;

/**
 * Range views filter.
 *
 * @ingroup views_filter_handlers
 *
 * @ViewsFilter("range")
 */
class Range extends FilterPluginBase {

  /**
   * {@inheritdoc}
   */
  public $operator = 'within';

  /**
   * {@inheritdoc}
   */
  protected $alwaysMultiple = TRUE;

  /**
   * {@inheritdoc}
   */
  protected function defineOptions() {
    $options = parent::defineOptions();

    $options['operator'] = array('default' => 'within');
    $options['value'] = array('default' => '');
    $options['include_endpoints'] = array('default' => FALSE);

    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function operatorOptions($which = 'title') {
    $options = array();
    foreach ($this->operators() as $id => $value) {
      $options[$id] = $value[$which];
    }

    return $options;
  }

  /**
   * {@inheritdoc}
   */
  protected function valueForm(&$form, FormStateInterface $form_state) {
    $form['value'] = array(
      '#type' => 'number',
      '#step' => 'any',
      '#title' => $this->t('Value'),
      '#size' => 30,
      '#default_value' => $this->value,
    );
    if (!$form_state->get('exposed')) {
      $form['include_endpoints'] = array(
        '#type' => 'checkbox',
        '#title' => $this->t('Include endpoints'),
        '#default_value' => $this->options['include_endpoints'],
        '#description' => $this->t('Whether to include endpoints or not.'),
      );
    }
  }

  /**
   * {@inheritdoc}
   */
  public function query() {
    $this->ensureMyTable();
    $field_from = "$this->tableAlias.{$this->definition['additional fields']['from']}";
    $field_to = "$this->tableAlias.{$this->definition['additional fields']['to']}";

    $operators = $this->operators();
    if (!empty($operators[$this->operator]['method'])) {
      $this->{$operators[$this->operator]['method']}($field_from, $field_to);
    }
  }

  /**
   * Operator callback.
   */
  protected function opWithin($field_from, $field_to) {
    $operators = array(
      '<', '>',
      '<=', '>=',
    );

    $inlude_endpoints = !($this->options['include_endpoints'] xor ($this->operator === 'within'));
    list($op_left, $op_right) = array_slice($operators, $inlude_endpoints ? 2 : 0, 2);

    if ($this->operator === 'within') {
      $this->query->addWhere($this->options['group'], db_and()->condition($field_from, $this->value, $op_left)->condition($field_to, $this->value, $op_right));
    }
    else {
      $this->query->addWhere($this->options['group'], db_or()->condition($field_from, $this->value, $op_right)->condition($field_to, $this->value, $op_left));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function adminSummary() {
    if ($this->isAGroup()) {
      return $this->t('grouped');
    }
    if (!empty($this->options['exposed'])) {
      return $this->t('exposed');
    }

    $options = $this->operatorOptions('short');
    return $options[$this->operator] . ' ' . $this->value;
  }

  /**
   * Define the operators supported for ranges.
   */
  protected function operators() {
    $operators = array(
      'within' => array(
        'title' => $this->t('Range contains'),
        'short' => $this->t('contains'),
        'method' => 'opWithin',
        'values' => 1,
      ),
      'not within' => array(
        'title' => $this->t('Range does not contain'),
        'short' => $this->t('does not contain'),
        'method' => 'opWithin',
        'values' => 1,
      ),
    );

    return $operators;
  }

}

==> range-8.x-1.2.tar.gz: range/src/Plugin/views/filter/Range.php <==
<?php

namespace Drupal\range\Plugin\views\filter;

use Drupal\Core\Database\Query\Condition;
use Drupal\Core\Form\FormStateInterface;
use Drupal\views\Plugin\views\filter\FilterPluginBase;

/**
 * Range views filter.
 *
 * @ingroup views_filter_handlers
 *
 * @ViewsFilter("range")
 */
class Range extends FilterPluginBase {

  /**
   * {@inheritdoc}
   */
  public $operator = 'within';

  /**
   * {@inheritdoc}
   */
  protected $alwaysMultiple = TRUE;

  /**
   * {@inheritdoc}
   */
  protected function defineOptions() {
    $options = parent::defineOptions();

    $options['operator'] = ['default' => 'within'];
    $options['value'] = ['default' => ''];
    $options['include_endpoints'] = ['default' => FALSE];

    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function operatorOptions($which = 'title') {
    $options = [];
    foreach ($this->operators() as $id => $value) {
      $options[$id] = $value[$which];
    }

    return $options;
  }

  /**
   * {@inheritdoc}
   */
  protected function valueForm(&$form, FormStateInterface $form_state) {
    $form['value'] = [
      '#type' => 'number',
      '#step' => 'any',
      '#title' => $this->t('Value'),
      '#size' => 30,
      '#default_value' => $this->value,
    ];
    if (!$form_state->get('exposed')) {
      $form['include_endpoints'] = [
        '#type' => 'checkbox',
        '#title' => $this->t('Include endpoints'),
        '#default_value' => $this->options['include_endpoints'],
        '#description' => $this->t('Whether to include endpoints or not.'),
      ];
    }
  }

  /**
   * {@inheritdoc}
   */
  public function query() {
    $this->ensureMyTable();
    $field_from = "$this->tableAlias.{$this->definition['additional fields']['from']}";
    $field_to = "$this->tableAlias.{$this->definition['additional fields']['to']}";

    $operators = $this->operators();
    if (!empty($operators[$this->operator]['method'])) {
      $this->{$operators[$this->operator]['method']}($field_from, $field_to);
    }
  }

  /**
   * Operator callback.
   */
  protected function opWithin($field_from, $field_to) {
    $operators = [
      '<', '>',
      '<=', '>=',
    ];

    $inlude_endpoints = !($this->options['include_endpoints'] xor ($this->operator === 'within'));
    list($op_left, $op_right) = array_slice($operators, $inlude_endpoints ? 2 : 0, 2);

    if ($this->operator === 'within') {
      $this->query->addWhere($this->options['group'], (new Condition('AND'))->condition($field_from, $this->value, $op_left)->condition($field_to, $this->value, $op_right));
    }
    else {
      $this->query->addWhere($this->options['group'], (new Condition('OR'))->condition($field_from, $this->value, $op_right)->condition($field_to, $this->value, $op_left));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function adminSummary() {
    if ($this->isAGroup()) {
      return $this->t('grouped');
    }
    if (!empty($this->options['exposed'])) {
      return $this->t('exposed');
    }

    $options = $this->operatorOptions('short');
    return $options[$this->operator] . ' ' . $this->value;
  }

  /**
   * Define the operators supported for ranges.
   */
  protected function operators() {
    $operators = [
      'within' => [
        'title' => $this->t('Range contains'),
        'short' => $this->t('contains'),
        'method' => 'opWithin',
        'values' => 1,
      ],
      'not within' => [
        'title' => $this->t('Range does not contain'),
        'short' => $this->t('does not contain'),
        'method' => 'opWithin',
        'values' => 1,
      ],
    ];

    return $operators;
  }

}
